From a6b697088c7972c975337a42493f8e016719bae4 Mon Sep 17 00:00:00 2001
From: Anders Lund <anders.lund@uninett.no>
Date: Mon, 30 Jun 2008 13:55:41 +0000
Subject: [PATCH] After earlier change attribute names are not lowercase. Fix
 for this.

git-svn-id: https://simplesamlphp.googlecode.com/svn/trunk@729 44740490-163a-0410-bde0-09ae8108e29a
---
 www/auth/login-feide.php | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/www/auth/login-feide.php b/www/auth/login-feide.php
index 5c7385438..2f1c9c46a 100644
--- a/www/auth/login-feide.php
+++ b/www/auth/login-feide.php
@@ -192,10 +192,10 @@ if (isset($_REQUEST['username'])) {
 		
 		
 		/**
 		 * Retrieve organizational attributes, if the edupersonorgdn attribute is set.
 		 */
-		if (isset($attributes['edupersonorgdn'])) {
-			$orgdn = $attributes['edupersonorgdn'][0];
+		if (isset($attributes['eduPersonOrgDN'])) {
+			$orgdn = $attributes['eduPersonOrgDN'][0];
 			$orgattributes = $ldap->getAttributes($orgdn);
 			
 			$orgattr = array_keys($orgattributes);
@@ -192,10 +192,10 @@ if (isset($_REQUEST['username'])) {
 		
 		/**
-		 * Retrieve organizational attributes, if the edupersonorgdn attribute is set.
+		 * Retrieve organizational attributes, if the eduPersonOrgDN attribute is set.
 		 */
-- 
GitLab